Index: code/branches/cpp11_v3/src/orxonox/collisionshapes/CollisionShape.cc
===================================================================
--- code/branches/cpp11_v3/src/orxonox/collisionshapes/CollisionShape.cc	(revision 11053)
+++ code/branches/cpp11_v3/src/orxonox/collisionshapes/CollisionShape.cc	(revision 11054)
@@ -57,7 +57,7 @@
         RegisterObject(CollisionShape);
 
-        this->parent_ = 0;
+        this->parent_ = nullptr;
         this->parentID_ = OBJECTID_UNKNOWN;
-        this->collisionShape_ = 0;
+        this->collisionShape_ = nullptr;
         this->position_ = Vector3::ZERO;
         this->orientation_ = Quaternion::IDENTITY;
@@ -154,5 +154,5 @@
     void CollisionShape::notifyDetached()
     {
-        this->parent_ = 0;
+        this->parent_ = nullptr;
         this->parentID_ = OBJECTID_UNKNOWN;
     }
Index: code/branches/cpp11_v3/src/orxonox/collisionshapes/CollisionShape.h
===================================================================
--- code/branches/cpp11_v3/src/orxonox/collisionshapes/CollisionShape.h	(revision 11053)
+++ code/branches/cpp11_v3/src/orxonox/collisionshapes/CollisionShape.h	(revision 11054)
@@ -61,5 +61,5 @@
             virtual ~CollisionShape();
 
-            virtual void XMLPort(Element& xmlelement, XMLPort::Mode mode);
+            virtual void XMLPort(Element& xmlelement, XMLPort::Mode mode) override;
 
             /**
@@ -181,5 +181,5 @@
 
             btCollisionShape*       collisionShape_; //!< The bullet collision shape of this CollisionShape.
-            CompoundCollisionShape* parent_; //!< The CompoundCollisionShape this CollisionShape belongs to, NULL if it doesn't belong to one.
+            CompoundCollisionShape* parent_; //!< The CompoundCollisionShape this CollisionShape belongs to, nullptr if it doesn't belong to one.
             unsigned int            parentID_; //!< The objectID of the parent of this CollisionShape, which can either be a CompoundCollisionShape or a WorldEntity.
 
Index: code/branches/cpp11_v3/src/orxonox/collisionshapes/CompoundCollisionShape.h
===================================================================
--- code/branches/cpp11_v3/src/orxonox/collisionshapes/CompoundCollisionShape.h	(revision 11053)
+++ code/branches/cpp11_v3/src/orxonox/collisionshapes/CompoundCollisionShape.h	(revision 11054)
@@ -61,5 +61,5 @@
             virtual ~CompoundCollisionShape();
 
-            virtual void XMLPort(Element& xmlelement, XMLPort::Mode mode);
+            virtual void XMLPort(Element& xmlelement, XMLPort::Mode mode) override;
 
             void attach(CollisionShape* shape);
@@ -70,10 +70,10 @@
             void updateAttachedShape(CollisionShape* shape);
 
-            virtual void changedScale();
+            virtual void changedScale() override;
 
         private:
             void updatePublicShape();
-            inline virtual btCollisionShape* createNewShape() const
-                { assert(false); return 0; }
+            virtual inline btCollisionShape* createNewShape() const override
+                { assert(false); return nullptr; }
 
             btCompoundShape* compoundShape_;
Index: code/branches/cpp11_v3/src/orxonox/collisionshapes/WorldEntityCollisionShape.cc
===================================================================
--- code/branches/cpp11_v3/src/orxonox/collisionshapes/WorldEntityCollisionShape.cc	(revision 11053)
+++ code/branches/cpp11_v3/src/orxonox/collisionshapes/WorldEntityCollisionShape.cc	(revision 11054)
@@ -43,5 +43,5 @@
         RegisterObject(WorldEntityCollisionShape);
 
-        this->worldEntityOwner_ = NULL;
+        this->worldEntityOwner_ = nullptr;
         // suppress synchronisation
         this->setSyncMode(ObjectDirection::None);
@@ -54,5 +54,5 @@
         CollisionShape::updateParent();
 
-        assert(this->worldEntityOwner_ != 0);
+        assert(this->worldEntityOwner_ != nullptr);
         this->worldEntityOwner_->notifyCollisionShapeChanged();
     }
Index: code/branches/cpp11_v3/src/orxonox/collisionshapes/WorldEntityCollisionShape.h
===================================================================
--- code/branches/cpp11_v3/src/orxonox/collisionshapes/WorldEntityCollisionShape.h	(revision 11053)
+++ code/branches/cpp11_v3/src/orxonox/collisionshapes/WorldEntityCollisionShape.h	(revision 11054)
@@ -46,8 +46,8 @@
 
         protected:
-            virtual void updateParent();
+            virtual void updateParent() override;
 
         private:
-            void parentChanged();
+            virtual void parentChanged() override;
 
             WorldEntity* worldEntityOwner_;

Index: code/branches/cpp11_v3/src/orxonox/collisionshapes/CompoundCollisionShape.cc
===================================================================
--- code/branches/cpp11_v3/src/orxonox/collisionshapes/CompoundCollisionShape.cc	(revision 11053)
+++ code/branches/cpp11_v3/src/orxonox/collisionshapes/CompoundCollisionShape.cc	(revision 11054)
@@ -65,17 +65,16 @@
         {
             // Delete all children
-            for (std::map<CollisionShape*, btCollisionShape*>::iterator it = this->attachedShapes_.begin();
-                it != this->attachedShapes_.end(); ++it)
+            for (const auto& mapEntry : this->attachedShapes_)
             {
                 // make sure that the child doesn't want to detach itself --> speedup because of the missing update
-                it->first->notifyDetached();
-                it->first->destroy();
-                if (this->collisionShape_ == it->second)
-                    this->collisionShape_ = NULL; // don't destroy it twice
+                mapEntry.first->notifyDetached();
+                mapEntry.first->destroy();
+                if (this->collisionShape_ == mapEntry.second)
+                    this->collisionShape_ = nullptr; // don't destroy it twice
             }
 
             delete this->compoundShape_;
             if (this->collisionShape_ == this->compoundShape_)
-                this->collisionShape_ = NULL; // don't destroy it twice
+                this->collisionShape_ = nullptr; // don't destroy it twice
         }
     }
@@ -96,5 +95,5 @@
     void CompoundCollisionShape::attach(CollisionShape* shape)
     {
         // If either the input shape is NULL or we try to attach the CollisionShape to itself.
         if (!shape || static_cast<CollisionShape*>(this) == shape)
             return;
@@ -197,16 +196,16 @@
     void CompoundCollisionShape::updatePublicShape()
     {
-        btCollisionShape* primitive = 0; // The primitive shape, if there is one.
+        btCollisionShape* primitive = nullptr; // The primitive shape, if there is one.
         bool bPrimitive = true; // Whether the CompoundCollisionShape has just one non-empty CollisionShape. And that shape also has no transformation.
         bool bEmpty = true; // Whether the CompoundCollisionShape is empty.
         // Iterate over all CollisionShapes that belong to this CompoundCollisionShape.
-        for (std::map<CollisionShape*, btCollisionShape*>::const_iterator it = this->attachedShapes_.begin(); it != this->attachedShapes_.end(); ++it)
+        for (const auto& mapEntry : this->attachedShapes_)
         {
             // TODO: Make sure this is correct.
-            if (it->second)
+            if (mapEntry.second)
             {
                 bEmpty = false;
-                if (!it->first->hasTransform() && bPrimitive)
-                    primitive = it->second;
+                if (!mapEntry.first->hasTransform() && bPrimitive)
+                    primitive = mapEntry.second;
                 else
                 {
@@ -221,7 +220,7 @@
         {
             // If there was none all along, nothing needs to be changed.
-            if (this->collisionShape_ == 0)
+            if (this->collisionShape_ == nullptr)
                 return;
-            this->collisionShape_ = 0;
+            this->collisionShape_ = nullptr;
         }
         // If the CompoundCollisionShape is just a primitive.
@@ -247,11 +246,11 @@
     {
         unsigned int i = 0;
-        for (std::map<CollisionShape*, btCollisionShape*>::const_iterator it = this->attachedShapes_.begin(); it != this->attachedShapes_.end(); ++it)
+        for (const auto& mapEntry : this->attachedShapes_)
         {
             if (i == index)
-                return it->first;
+                return mapEntry.first;
             ++i;
         }
-        return 0;
+        return nullptr;
     }
 
@@ -267,6 +266,6 @@
         std::vector<CollisionShape*> shapes;
         // Iterate through all attached CollisionShapes and add them to the list of shapes.
-        for(std::map<CollisionShape*, btCollisionShape*>::iterator it = this->attachedShapes_.begin(); it != this->attachedShapes_.end(); it++)
-            shapes.push_back(it->first);
+        for(const auto& mapEntry : this->attachedShapes_)
+            shapes.push_back(mapEntry.first);
 
         // Delete the compound shape and create a new one.
@@ -275,7 +274,6 @@
 
         // Re-attach all CollisionShapes.
-        for(std::vector<CollisionShape*>::iterator it = shapes.begin(); it != shapes.end(); it++)
-        {
-            CollisionShape* shape = *it;
+        for(CollisionShape* shape : shapes)
+        {
             shape->setScale3D(this->getScale3D());
             // Only actually attach if we didn't pick a CompoundCollisionShape with no content.
@@ -96,5 +95,5 @@
     void CompoundCollisionShape::attach(CollisionShape* shape)
     {
-        // If either the input shape is NULL or we try to attach the CollisionShape to itself.
+        // If either the input shape is nullptr or we try to attach the CollisionShape to itself.
         if (!shape || static_cast<CollisionShape*>(this) == shape)
             return;